Merge branch 'readonly-p4-master'
diff --git a/build/sdk-darwin-x86.atree b/build/sdk-darwin-x86.atree
index 26bbd1c..13ed592 100644
--- a/build/sdk-darwin-x86.atree
+++ b/build/sdk-darwin-x86.atree
@@ -10,8 +10,10 @@
 framework/org.eclipse.jface_3.2.0.I20060605-1400.jar tools/lib/org.eclipse.jface_3.2.0.I20060605-1400.jar
 
 # JetCreator (only available on mac/windows)
-external/sonivox/jet_tools/JetCreator tools/JetCreator
-prebuilt/darwin-x86/jetcreator/libEASLIb.dylib tools/JetCreator/libEASLIb.dylib
+external/sonivox/jet_tools/JetCreator tools/Jet/JetCreator
+prebuilt/darwin-x86/jetcreator/libEASLIb.dylib tools/Jet/JetCreator/libEASLIb.dylib
+external/sonivox/jet_tools/JetCreator_content tools/Jet/demo_content
+external/sonivox/jet_tools/logic_templates tools/Jet/logic_templates
 
 external/sonivox/docs/JET_Authoring_Guidelines.html docs/JetCreator/JET_Authoring_Guidelines.html
 external/sonivox/docs/JET_Authoring_Guidelines_files docs/JetCreator/JET_Authoring_Guidelines_files
diff --git a/build/tools/make_windows_sdk.sh b/build/tools/make_windows_sdk.sh
index acca6c7..ba68120 100755
--- a/build/tools/make_windows_sdk.sh
+++ b/build/tools/make_windows_sdk.sh
@@ -139,24 +139,31 @@
     cp -v development/tools/draw9patch/etc/draw9patch.bat "$TOOLS"
     cp -v development/tools/sdkmanager/app/etc/android.bat "$TOOLS"
     
-    # Put the JetCreator tools (not available in the linux SDK)
-    JETCREATOR="$TOOLS/JetCreator"
+    # Put the JetCreator tools, content and docs (not available in the linux SDK)
+    JET="$TOOLS/Jet"
+    JETCREATOR="$JET/JetCreator"
+    JETDEMOCONTENT="$JET/demo_content"
+    JETLOGICTEMPLATES="$JET/logic_templates"
     JETDOC="$DEST/docs/JetCreator"
 
     # need to rm these folders since a Mac SDK will have them and it would create a conflict
-    rm -rfv "$JETCREATOR"
+    rm -rfv "$JET"
     rm -rfv "$JETDOC"
 
     # now create fresh folders for JetCreator
-    mkdir "$JETCREATOR"
+    mkdir "$JET"
     mkdir "$JETDOC"
 
     cp -rv external/sonivox/jet_tools/JetCreator "$JETCREATOR"
-    cp -v prebuilt/windows/jetcreator/EASDLL.dll "$JETCREATOR" 
-    cp -v external/sonivox/docs/JET_Authoring_Guidelines.html "$JETDOC"
-    cp -rv external/sonivox/docs/JET_Authoring_Guidelines_files/* docs/JetCreator/JET_Authoring_Guidelines_files
-    cp -v external/sonivox/docs/JET_Creator_User_Manual.html "$JETDOC"
-    cp -rv external/sonivox/docs/JET_Creator_User_Manual_files/* docs/JetCreator/JET_Creator_User_Manual_files
+    cp -v prebuilt/windows/jetcreator/EASDLL.dll "$JETCREATOR"
+    cp -v prebuilt/windows/jetcreator/EASDLL.dll "$JETCREATOR"
+    cp -rv external/sonivox/jet_tools/JetCreator_content "$JETDEMOCONTENT"
+    cp -rv external/sonivox/jet_tools/logic_templates "$JETLOGICTEMPLATES"
+    
+    cp -v external/sonivox/docs/JET_Authoring_Guidelines.html "$JETDOC"/
+    cp -rv external/sonivox/docs/JET_Authoring_Guidelines_files "$JETDOC"/
+    cp -v external/sonivox/docs/JET_Creator_User_Manual.html "$JETDOC"/
+    cp -rv external/sonivox/docs/JET_Creator_User_Manual_files "$JETDOC"/
 
     # Copy or move platform specific tools to the default platform.
     cp -v dalvik/dx/etc/dx.bat "$PLATFORM_TOOLS"